@@ -1,19 +1,20 @@
+from __future__ import annotations
+
 import json
 import urllib.request
 from typing import Any
 from typing import Dict
 from typing import List
 from typing import NamedTuple
-from typing import Optional
 from typing import TypeVar
 
 
 class Response(NamedTuple):
     json: Any
-    links: Dict[str, str]
+    links: dict[str, str]
 
 
-def _parse_link(lnk: Optional[str]) -> Dict[str, str]:
+def _parse_link(lnk: str | None) -> dict[str, str]:
     if lnk is None:
         return {}
 
@@ -34,8 +35,8 @@ def req(url: str, **kwargs: Any) -> Response:
     return Response(json.load(resp), _parse_link(resp.headers['link']))
 
 
-def get_all(url: str, **kwargs: Any) -> List[Dict[str, Any]]:
-    ret: List[Dict[str, Any]] = []
+def get_all(url: str, **kwargs: Any) -> list[dict[str, Any]]:
+    ret: list[dict[str, Any]] = []
     resp = req(url, **kwargs)
     ret.extend(resp.json)
     while 'next' in resp.links:
@@ -52,9 +53,9 @@ def _strip_trailing_dot_git(ssh_url: str) -> str:
 
 
 def filter_repos(
-        repos: List[Dict[str, Any]], *,
+        repos: list[dict[str, Any]], *,
         forks: bool, private: bool, collaborator: bool, archived: bool,
-) -> Dict[str, str]:
+) -> dict[str, str]:
     return {
         repo['full_name']: _strip_trailing_dot_git(repo['ssh_url'])
         for repo in repos
