@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import json
-from typing import Dict
 from typing import NamedTuple
 
 
@@ -7,6 +8,6 @@ class Settings(NamedTuple):
     filename: str
 
 
-def list_repos(settings: Settings) -> Dict[str, str]:
+def list_repos(settings: Settings) -> dict[str, str]:
     with open(settings.filename) as f:
         return json.load(f)
