@@ -1,5 +1,5 @@
-from typing import List
-from typing import Tuple
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -10,7 +10,7 @@ else:
 
 class NamedTupleProtocol(Protocol):
     @property
-    def _fields(self) -> Tuple[str, ...]: ...
+    def _fields(self) -> tuple[str, ...]: ...
 
 
 def hide_api_key_repr(nt: NamedTupleProtocol, *, key: str = 'api_key') -> str:
@@ -23,7 +23,7 @@ def hide_api_key_repr(nt: NamedTupleProtocol, *, key: str = 'api_key') -> str:
     return f'{type(nt).__name__}(\n{fields})'
 
 
-def zsplit(bs: bytes) -> List[bytes]:
+def zsplit(bs: bytes) -> list[bytes]:
     if bs:
         return bs.rstrip(b'\0').split(b'\0')
     else:
